from distutils.core import setup

from setuptools import find_packages

setup(name="xfile_selector",
      version="0.0.1",
      description="文件选择器",
      long_description="terminal or other platform",
      author="xyt",
      author_email="2506564278@qq.com",
      license="<MIT License>",
      packages=find_packages(),
      url="https://gitee.com/jimonik/xbase_util.git",
      install_requires=[

      ],
      zip_safe=False,
      package_data={
            'xbase_util': ['../xbase_util_assets/*']
      },
      include_package_data=True)
